TemporaryStore

Struct TemporaryStore 

pub struct TemporaryStore<'backing> { /* private fields */ }

Implementations

Source

impl<'backing> TemporaryStore<'backing>

pub fn load_implicitly_read_system_object( &self, object_id: &ObjectID, ) -> Option<Object>

Checks that the system object object_id is available at the version this transaction requires, and records the read so it can be emitted into effects and reproduced on replay. This is expected to return Some in normal cases. If it ever returns None, it should be treated as an invariant violation.

pub fn unsettled_object_funds(&self) -> &dyn UnsettledObjectFundsRead

pub fn objects(&self) -> &BTreeMap<ObjectID, Object>

pub fn update_object_version_and_prev_tx(&mut self)

pub fn into_inner( self, accumulator_running_max_withdraws: BTreeMap<AccumulatorObjId, u128>, ) -> InnerTemporaryStore

Break up the structure and return its internal stores (objects, active_inputs, written, deleted)

pub fn into_effects( self, shared_object_refs: Vec<SharedInput>, transaction_digest: &TransactionDigest, transaction_dependencies: BTreeSet<TransactionDigest>, gas_cost_summary: GasCostSummary, status: ExecutionStatus, gas_coin: Option<ObjectID>, epoch: EpochId, ) -> (InnerTemporaryStore, TransactionEffects)

pub fn mutate_input_object(&mut self, object: Object)

Mutate a mutable input object. This is used to mutate input objects outside of PT execution.

pub fn mutate_new_or_input_object(&mut self, object: Object)

pub fn mutate_child_object(&mut self, old_object: Object, new_object: Object)

Mutate a child object outside of PT. This should be used extremely rarely. Currently it’s only used by advance_epoch_safe_mode because it’s all native without PT. This should almost never be used otherwise.

pub fn upgrade_system_package(&mut self, package: Object)

Upgrade system package during epoch change. This requires special treatment since the system package to be upgraded is not in the input objects. We could probably fix above to make it less special.

pub fn create_object(&mut self, object: Object)

Crate a new objcet. This is used to create objects outside of PT execution.

pub fn delete_input_object(&mut self, id: &ObjectID)

Delete a mutable input object. This is used to delete input objects outside of PT execution.

pub fn drop_writes(&mut self)

pub fn read_object(&self, id: &ObjectID) -> Option<&Object>

pub fn save_loaded_runtime_objects( &mut self, loaded_runtime_objects: BTreeMap<ObjectID, DynamicallyLoadedObjectMetadata>, )

pub fn save_wrapped_object_containers( &mut self, wrapped_object_containers: BTreeMap<ObjectID, ObjectID>, )

pub fn save_generated_object_ids(&mut self, generated_ids: BTreeSet<ObjectID>)

pub fn estimate_effects_size_upperbound(&self) -> usize

pub fn written_objects_size(&self) -> usize

pub fn conserve_unmetered_storage_rebate( &mut self, unmetered_storage_rebate: u64, )

If there are unmetered storage rebate (due to system transaction), we put them into the storage rebate of 0x5 object. TODO: This will not work for potential future new system transactions if 0x5 is not in the input. We should fix this.

pub fn add_accumulator_event(&mut self, event: AccumulatorEvent)

Add an accumulator event to the execution results.

pub fn protocol_config(&self) -> &'backing ProtocolConfig

Source

impl TemporaryStore<'_>

Source

impl TemporaryStore<'_>

pub fn advance_epoch_safe_mode( &mut self, params: &AdvanceEpochParams, protocol_config: &ProtocolConfig, )